@@ -7,7 +7,7 @@ import logging
 logging.basicConfig(level=logging.INFO)
 
 bed_file = '../data/mouse_long/plink'
-# agmat(bed_file, out_file='../data/mouse_long/test', out_fmt='id_id_val')
+#agmat(bed_file, out_file='../data/mouse_long/test', out_fmt='id_id_val')
 data_file = '../data/mouse_long/phe.unbalance.txt'
 id = 'ID'
 tpoint = 'weak'
@@ -15,7 +15,7 @@ trait = 'trait'
 agmat_file = '../data/mouse_long/test'
 tfix = 'Sex'
 prefix_outfile = '../data/mouse_long/unbalance_varcom'
-# res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, tfix="Sex", out_file=prefix_outfile)
+#res_var = unbalance_varcom(data_file, id, tpoint, trait, agmat_file, tfix="Sex", out_file=prefix_outfile)
 # print(res_var)
 
 var_com = pd.read_csv("../data/mouse_long/unbalance_varcom.var", sep='\s+', header=0)
@@ -41,8 +41,9 @@ res_trans = unbalance_longwas_trans(data_file, id, tpoint, trait, bed_file, agma
 """
 from gmat.longwas.unbalance import unbalance_condition_longwas_trans
 
-prefix_outfile = '../data/mouse_long/unbalance_condition_longwas_trans'
-res_trans = unbalance_condition_longwas_trans(data_file, id, tpoint, trait, bed_file, agmat_file, var_com, condition_snp="UNC30664376", tfix="Sex", fix="Sex",
+prefix_outfile = '../data/mouse_long/unbalance_condition_longwas_trans8'
+res_trans = unbalance_condition_longwas_trans(data_file, id, tpoint, trait, bed_file, agmat_file, 
+      var_com, condition_snp="UNC30664376", tfix='Sex', fix="Sex", crank=True,
                                     prefix_outfile=prefix_outfile)
 """
 from gmat.longwas.unbalance import unbalance_longwas_fixed_permutation
