@@ -7,21 +7,23 @@ from tqdm import tqdm
 from gmat.process_plink.process_plink import impute_geno
 from scipy.stats import chi2
 from scipy.sparse import csc_matrix
+from patsy import dmatrix
 
 
-def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', condition=None, npart=100, maxiter0=100, maxiter1=10,
-          speed=True, pcut=5.0e-5):
+def fixed(pheno_file, bed_file, agmat_file, class_lst=None, fix=None, out_file='res.txt', condition_snp=None, npart=100,
+          maxiter0=100, maxiter1=10, speed=True, pcut=5.0e-5):
     """
     run GWAS based on linear mixed model and put one snp in each analysis.
-    :param pheno_file: phenotypic file. The fist column is individual id . The second column is always a column of 1s
-    for population mean. The last column is phenotypic values. The other covariates can be added between columns for
-    population mean and phenotypic values. Missing values in the phenotypic file can be
-    expressed as 'NA', 'NaN', 'nan' or 'na'.
+    :param pheno_file: phenotypic file with head rows. The fist column is individual id. The last column is phenotypic values.
+    Class variates and covariates are in the middle columns. Missing values in the phenotypic file can be
+    expressed as 'NA', 'NaN', 'nan', 'na'.
     :param bed_file: the prefix for the plink binary file.
     :param agmat_file: the prefix for the additive genomic relationship matrix file.
+    :param class_lst: a list for class variates
+    :param fix: formula for the fix effect. Eg. fix='sex + herd'
     :param out_file: the output file. Default is 'res.txt'.
-    :param condition: A string or a list for the conditional SNP. Default is None.
-    :param npart: divide the SNPs into n parts. Default is 100.
+    :param condition_snp: A string or a list for the conditional SNP. Default is None.
+    :param npart: divide the SNPs into n parts and read them into memory successively. Default is 100.
     :param maxiter0: the maximum number of iteration for variance estimation in the null model
     :param maxiter1: the maximum number of iteration for variance estimation in testing snp.
     :param speed: whether to speed up with estimated variances in the null model.
@@ -29,7 +31,7 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', condition=None,
     :return:
     """
     logging.info("###Prepare the phenotypic values, covariates and genomic matrix")
-    y, xmat, zmat, ag, id_keep = _pre_pheno(pheno_file, agmat_file)
+    y, xmat, zmat, ag, id_keep = _pre_pheno(pheno_file, agmat_file, class_lst, fix)
     logging.info("###Estimate the variances in the null model.")
     init = np.array([np.var(y) / 2] * 2)
     gmat_eigenvals, gmat_eigenvecs = linalg.eigh(zmat.dot((zmat.dot(ag)).T))
@@ -50,10 +52,11 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', condition=None,
     for i in range(npart):
         snp_index.append(int(num_snp / npart) * i)
     snp_index.append(num_snp)
-    if condition is not None:
-        if not isinstance(condition, list):
-            condition = [condition]
-        condition_snp_index = snp_on_disk.sid_to_index(condition)
+    logging.info("Conditional SNP: {}".format(condition_snp))
+    if condition_snp is not None:
+        if not isinstance(condition_snp, list):
+            condition_snp = [condition_snp]
+        condition_snp_index = snp_on_disk.sid_to_index(condition_snp)
         condition_snp_val = snp_on_disk[id_keep_ind, condition_snp_index].read().val
         if np.any(np.isnan(condition_snp_val)):
             logging.info('Missing genotypes of conditional SNP are imputed with random genotypes.')
@@ -150,28 +153,39 @@ def fixed(pheno_file, bed_file, agmat_file, out_file='res.txt', condition=None,
     return 0
 
 
-def _pre_pheno(pheno_file, agmat_file):
+def _pre_pheno(pheno_file, agmat_file, class_lst, fix):
     id_in_agmat = []
     with open(agmat_file + '.id') as fin:
         for line in fin:
             arr = line.split()
             id_in_agmat.append(arr[0])
-    y = []
-    xmat = []
+    data_df = pd.read_csv(pheno_file, sep='\s+', header=0)
+    data_df = data_df.dropna()
+    col_names = data_df.columns
+    class_lst2 = [col_names[0]]
+    if class_lst is not None:
+        class_lst2 = class_lst + class_lst2
+    for val in col_names:
+        if val in class_lst2:
+            data_df[val] = data_df[val].astype('str')
+        else:
+            data_df[val] = data_df[val].astype('float')
     id_keep = []  # keep the id both in the agmat file and pheno file, without missing phenotypes and covariates.
-    with open(pheno_file) as fin:
-        for line in fin:
-            arr = line.split()
-            if arr[0] in id_in_agmat:
-                try:
-                    vec = np.array(arr[1:], dtype=float)
-                    y.append(vec[-1])
-                    xmat.append(vec[:-1])
-                    id_keep.append(arr[0])
-                except Exception as e:
-                    del e
-    y = np.array(y).reshape(-1, 1)
-    xmat = np.array(xmat)
+    for i in range(data_df.shape[0]):
+        if data_df.iloc[i, 0] in id_in_agmat:
+            id_keep.append(True)
+        else:
+            id_keep.append(False)
+    data_df = data_df.iloc[id_keep, :]
+    id_keep = list(data_df.iloc[:, 0])
+    y = np.array(data_df.iloc[:, -1]).reshape(-1, 1)
+    xmat = np.ones((y.shape[0], 1))
+    if fix is not None:
+        xmat = dmatrix(fix, data_df)
+        xmat = np.asarray(xmat)
+        _, r = np.linalg.qr(xmat)
+        indexes = np.absolute(np.diag(r)) >= 1e-10
+        xmat = xmat[:, indexes]
     val = 0
     id_dct = {}
     col = []
